"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const TRANSFORM_FIELDS = {
    replyTo: 'Reply-To'
};
const TO_KEYS = ['to', 'cc', 'bcc'];
const HEADERS = ['replyTo'];
class Mandrill {
    constructor(apiKey) {
        this.key = apiKey;
    }
    getFromName(data) {
        if (data.from) {
            return data.from.name || '';
        }
        return '';
    }
    getFromAddress(data) {
        if (data.from) {
            return data.from.address || '';
        }
        return '';
    }
    appendAddresses(data) {
        return TO_KEYS.reduce((accumulator, target) => {
            if (!data[target])
                return accumulator;
            data[target].forEach(to => {
                accumulator.push({
                    email: to.address,
                    name: to.name,
                    type: target
                });
            });
            return accumulator;
        }, []);
    }
    appendAttachments(data) {
        if (!Array.isArray(data.attachments))
            return [];
        return data.attachments.reduce((accumulator, attachment) => {
            if (!attachment.contentType.startsWith('image/')) {
                accumulator.push({
                    name: attachment.filename || attachment.cid,
                    type: attachment.contentType,
                    content: attachment.content
                });
            }
            return accumulator;
        }, []);
    }
    appendImages(data) {
        if (!Array.isArray(data.attachments))
            return [];
        return data.attachments.reduce((accumulator, attachment) => {
            if (attachment.contentType.startsWith('image/')) {
                accumulator.push({
                    name: attachment.cid,
                    type: attachment.contentType,
                    content: attachment.content
                });
            }
            return accumulator;
        }, []);
    }
    appendHeaders(data) {
        return HEADERS.reduce((headers, key) => {
            if (data[key]) {
                headers[TRANSFORM_FIELDS[key] || key] = data[key];
            }
            return headers;
        }, {});
    }
    setMessage(data) {
        this.message = {
            html: data.html,
            text: data.text,
            subject: data.subject,
            from_email: this.getFromAddress(data),
            from_name: this.getFromName(data),
            to: this.appendAddresses(data),
            headers: this.appendHeaders(data),
            attachments: this.appendAttachments(data),
            images: this.appendImages(data)
        };
    }
}
exports.Mandrill = Mandrill;
